@@ -769,6 +769,10 @@ submit -p @@file=globnat:indeck* sim.exe @@file
          self.parser.add_option("-p","--parameters",action="callback",
                                                     callback=self.__grabMultipleParameterArguments,dest="parameters",
                                                     help="Parameter sweep variables terminated by --. See examples.")
+         self.parser.add_option("--json",action="callback",
+                                         callback=self.__grabMultipleStringArguments,dest="jsonArgs",
+                                         callback_kwargs={'isOptional':False},
+                                         help="File containing submit arguments, JSON format, terminated by --.")
       else:
          self.parser.add_option("-v","--venue",action="callback",
                                                callback=self.__grabStringArgument,dest="destinations",
@@ -785,6 +789,13 @@ submit -p @@file=globnat:indeck* sim.exe @@file
          self.parser.add_option("-p","--parameters",action="callback",
                                                     callback=self.__grabParameterArgument,dest="parameters",
                                                     help="Parameter sweep variables. See examples.")
+         self.parser.add_option("--json",action="callback",
+                                         callback=self.__grabStringArgument,dest="jsonArgs",
+                                         callback_kwargs={'isOptional':False},
+                                         help="File containing submit arguments, JSON format.")
+
+      self.parser.add_option("--savejson",action="store",type="string",dest="saveJson",
+                                          help="Save submit arguments to JSON file for possible reuse.")
 
       self.parser.add_option("-d","--data",action="callback",
                                            callback=self.__grabStringArgument,dest="csvData",
@@ -798,10 +809,16 @@ submit -p @@file=globnat:indeck* sim.exe @@file
                                             help="Number of processors for MPI execution")
       self.parser.add_option("-N","--ppn",action="store",type="int",dest="ppn",
                                           help="Number of processors/node for MPI execution")
+      self.parser.add_option("-g","--nGpus",action="store",type="int",dest="nGpus",
+                                            help="Number of GPUs")
+      self.parser.add_option("-G","--gpn",action="store",type="int",dest="gpn",
+                                          help="Number of GPUs/node")
       self.parser.add_option("--stripes",action="store",type="int",dest="nStripes",
                                          help="Number of parallel local jobs when doing parametric sweep")
       self.parser.add_option("-w","--wallTime",action="store",type="string",dest="wallTime",
                                                help="Estimated walltime hh:mm:ss or minutes")
+      self.parser.add_option("--memory",action="store",type="int",dest="memoryMB",
+                                        help="Memory requirement for each node (MB).")
       self.parser.add_option("-e","--env",action="callback",
                                           callback=self.__grabStringArgument,dest="environment",
                                           callback_kwargs={'isOptional':False},
@@ -865,6 +882,10 @@ submit -p @@file=globnat:indeck* sim.exe @@file
                                           help="Show progress method." +
                                                " Choices are auto, curses, submit, text, pegasus, or silent.")
 
+      self.parser.set_defaults(showCommand=False)
+      self.parser.add_option("--show",action="store_true",dest="showCommand",
+                                      help="Echo submit command to stdout.")
+
       self.parser.set_defaults(doHeartbeat=True)
       self.parser.add_option("--noHeartbeat",action="store_false",dest="doHeartbeat",
                                              help=SUPPRESS_HELP)
